#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-app-static
version: 3.1.5
id: wai-app-static-3.1.5-9c470d1531d667f785392fcc70a11537
key: waiap_2AWvqPnfuH7GsfwLiTEpQb
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/web-application-interface
synopsis: WAI application for static serving
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-app-static>.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Network.Wai.Application.Static WaiAppStatic.Storage.Filesystem
    WaiAppStatic.Storage.Embedded WaiAppStatic.Listing
    WaiAppStatic.Types WaiAppStatic.CmdLine
hidden-modules: Util WaiAppStatic.Storage.Embedded.Runtime
                WaiAppStatic.Storage.Embedded.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.5
library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-app-static-3.1.5
data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-app-static-3.1.5
hs-libraries: HSwai-app-static-3.1.5-2AWvqPnfuH7GsfwLiTEpQb
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.2-290873936811c5be5456133d1e8642df
    blaze-html-0.8.1.1-196db2ddcb827bc04473411dd00dd5eb
    blaze-markup-0.7.0.3-301d79472dd24aabecf5f1be193f6bdb
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    cryptonite-0.15-52f487cbd51518538a9e7cbc4eddf82b
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    file-embed-0.0.10-c7da10dfba0f55c7c135317c0bfb8508
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    http-date-0.0.6.1-4ea0001d3f50118f98db684749e0642e
    http-types-0.9-abc209b9e91b870b477d7ec7669b4ae8
    memory-0.12-092368f288b8a5ed89de3a4f849c43f2
    mime-types-0.1.0.7-9c54fcb2a9f57168849ef5415f3582c2
    old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
    optparse-applicative-0.12.1.0-efdb53d7ee5eb339e181252750b5ba21
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unix-compat-0.4.1.4-baa19ce04d0e8a47661438a80ea2aec8
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
    wai-3.2.1-82fcd8afd3d66bf63829f2c0f9ec2308
    wai-extra-3.0.15.1-954bd1f4cbd0dadcc30817e6afe9d17a
    warp-3.2.6-747ccbb2aaea6b63942f452bd0d269ae
    zlib-0.6.1.1-863f5ed4c9ef7e591295c362d5c5d2a5
haddock-interfaces: /usr/share/doc/haskell-wai-app-static/html/wai-app-static.haddock
haddock-html: /usr/share/doc/haskell-wai-app-static/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
